@@ -6,7 +6,11 @@ from .client_resource import SingleClientResource, ClientManager, ClientRoleMana
 from .custom_authentication_resource import SingleCustomAuthenticationResource
 # from .role_resource import RoleResource
 from .realm_role_resource import RealmRoleManager, RealmRoleResource
-from .client_scope_resource import ClientScopeResource
+from .client_scope_resource import ClientScopeResource, ClientScopeScopeMappingsRealmManager, \
+    ClientScopeProtocolMapperResource, ClientScopeProtocolMapperManager, \
+    ClientScopeScopeMappingsClientManager, ClientScopeScopeMappingsAllClientsManager, \
+    ClientScopeManager
+from .default_client_scope_resource import DefaultDefaultClientScopeManager, DefaultOptionalClientScopeManager
 from .identity_provider_resource import IdentityProviderResource, IdentityProviderMapperResource
 from .identity_provider_resource import IdentityProviderManager, IdentityProviderMapperManager
 from .user_federation_resource import UserFederationResource
